@@ -144,11 +144,21 @@ lo_message lo_message_new(void);
  *
  * Messages are reference counted. If a message is multiply referenced,
  * the message's counter should be incremented. It is automatically
- * decremented by lo_message_free lo_message_free_recursive, with
- * lo_message_free_recursive being the preferable method.
+ * decremented by `lo_message_free` or `lo_bundle_free_recursive`, with
+ * `lo_bundle_free_recursive` being the preferable method if bundles are used.
  */
 void lo_message_incref(lo_message m);
 
+/**
+ * \brief Subtract one from a message's reference count.
+ *
+ * Messages are reference counted. In general decrementing the counter
+ * should be handled automatically using `lo_message_free` or
+ * `lo_bundle_free_recursive`, however if necessary the counter can be
+ * decremented manually.
+ */
+int lo_message_decref(lo_message m);
+
 /**
  * \brief Create a new lo_message object by cloning an already existing one
  */
@@ -160,6 +170,11 @@ lo_message lo_message_clone(lo_message m);
  */
 void lo_message_free(lo_message m);
 
+/**
+ * \brief Clear elements from a lo_message but do not free allocated memory.
+ */
+void lo_message_clear(lo_message m);
+
 /**
  * \brief Append a number of arguments to a message.
  *
@@ -688,9 +703,9 @@ lo_hires lo_hires_val(lo_type type, lo_arg *p);
  * \brief Create a new server instance.
  *
  * Using lo_server_recv(), lo_servers block until they receive OSC
- * messages.  If you want non-blocking behaviour see
- * lo_server_recv_noblock() or the \ref lo_server_thread_new
- * "lo_server_thread_*" functions.
+ * messages.  Most likely you want non-blocking behaviour, so use of
+ * lo_server_recv_noblock() is encouraged or the \ref lo_server_thread_new
+ * and "lo_server_thread_*" functions.
  *
  * \param port If NULL is passed then an unused UDP port will be chosen by the
  * system, its number may be retrieved with lo_server_thread_get_port()
@@ -706,9 +721,9 @@ lo_server lo_server_new(const char *port, lo_err_handler err_h);
  * \brief Create a new server instance, specifying protocol.
  *
  * Using lo_server_recv(), lo_servers block until they receive OSC
- * messages.  If you want non-blocking behaviour see
- * lo_server_recv_noblock() or the \ref lo_server_thread_new
- * "lo_server_thread_*" functions.
+ * messages.  Most likely you want non-blocking behaviour, so use of
+ * lo_server_recv_noblock() is encouraged or the \ref lo_server_thread_new
+ * and "lo_server_thread_*" functions.
  *
  * \param port If using UDP then NULL may be passed to find an unused port.
  * Otherwise a decimal port number orservice name or may be passed.
@@ -799,9 +814,12 @@ void lo_server_free(lo_server s);
  * \param timeout A timeout in milliseconds to wait for the incoming packet.
  * a value of 0 will return immediately.
  *
- * The return value is 1 if there is a message waiting or 0 if
- * there is no message. If there is a message waiting you can now
- * call lo_server_recv() to receive that message.
+ * The return value is 1 if there is a message waiting, 0 if
+ * there is no message, and -1 if there is an error that causes the
+ * function to return early. If there is a message waiting you can now
+ * call lo_server_recv() to receive that message. This is preferable
+ * to using lo_server_recv() alone, since otherwise it may never exit
+ * if no new messages are incoming.
  */
 int lo_server_wait(lo_server s, int timeout);
 
@@ -815,14 +833,18 @@ int lo_server_wait(lo_server s, int timeout);
  * a value of 0 will return immediately.
  *
  * The return value is the number of servers with a message waiting or
- * 0 if there is no message. If there is a message waiting you can now
- * call lo_server_recv() to receive that message.
+ * -1 if there is an error that causes the function to return early.
+ * If there is a message waiting you can now call lo_server_recv()
+ * to receive that message. This is preferable to using lo_server_recv()
+ * alone, since otherwise it may never exit if no new messages are incoming.
  */
 int lo_servers_wait(lo_server *s, int *status, int num_servers, int timeout);
 
 /**
  * \brief Look for an OSC message waiting to be received
  *
+ * In new programs, this function should be prefered over lo_server_recv().
+ *
  * \param s The server to wait for connections on.
  * \param timeout A timeout in milliseconds to wait for the incoming packet.
  * a value of 0 will return immediately.
@@ -852,8 +874,15 @@ int lo_servers_recv_noblock(lo_server *s, int *recvd, int num_servers,
 /**
  * \brief Block, waiting for an OSC message to be received
  *
+ * The blocking behavior of this function is, in most cases,
+ * undesireable, since a program with no incoming messages may never
+ * exit. It is encouraged to use lo_server_recv_noblock() instead,
+ * which is equivalent to lo_server_wait() and then lo_server_recv().
+ *
  * The return value is the number of bytes in the received message. The message
- * will be dispatched to a matching method if one is found.
+ * will be dispatched to a matching method if one is found. In cases where no
+ * message is received but returning is necessary anyway, this function may
+ * return 0.
  */
 int lo_server_recv(lo_server s);
 
