@@ -1400,6 +1400,8 @@ void test_server_thread(lo_server_thread *pst, lo_address *pa)
             -0.00000023001f, 1.0);
     lo_send(a, "/a/b/c/d", "b", btest);
 
+    SLEEP_MS(1000);
+
     /* Delete methods */
     lo_server_thread_del_method(st, "/coerce", "dfhiSs");
     TEST (lo_server_thread_del_lo_method(st, jit) == 0);
@@ -1569,7 +1571,7 @@ void test_bundle(lo_server_thread st, lo_address a)
     lo_send_bundle(a, b);
 
     /* This should be safe for multiple copies of the same message. */
-    lo_bundle_free_messages(b);
+    lo_bundle_free_recursive(b);
 
     {
         lo_timetag t = { 1, 2 };
@@ -1618,8 +1620,8 @@ void test_bundle(lo_server_thread st, lo_address a)
     lo_message_add_string(m1, "ABCDEFGHIJKLMNOPQRSTUVWXYZ");
     lo_bundle_add_message(b, "/bundle", m1);
     lo_send_bundle(a, b);
-    lo_message_free(m1);
     lo_bundle_free(b);
+    lo_message_free(m1);
 
     lo_timetag_now(&sched);
 
@@ -1632,8 +1634,8 @@ void test_bundle(lo_server_thread st, lo_address a)
     lo_bundle_add_message(b, "/bundle", m1);
 
     lo_send_bundle(a, b);
-    lo_message_free(m1);
     lo_bundle_free(b);
+    lo_message_free(m1);
 
     lo_send_timestamped(a, sched, "/bundle", "s",
                         "lo_send_timestamped() test");
